/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mozilla Communicator client code, released
 * March 31, 1998.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998-1999
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

/* This contains CSS just for smiley menu */

#smileButton {
  list-style-image:url("chrome://editor/content/images/smile.gif"); 
}

menu:hover > #smileButton, 
menu:hover:active > #smileButton[toggled="true"] {
	list-style-image:url("chrome://editor/content/images/smile_hover.gif");
}

menu:hover:active > #smileButton,
menu:hover > #smileButton[toggled="true"] {
	list-style-image:url("chrome://editor/content/images/smile_active.gif");
}

#smileButton[disabled="true"], 
menu:hover > #smileButton[disabled="true"], 
menu:hover:active > #smileButton[disabled="true"] {
	list-style-image:url("chrome://editor/content/images/smile_disabled.gif");
}


#insert-smile {

   list-style-image:url(chrome://editor/content/images/smile.gif);
}

#insert-frown {
   list-style-image:url(chrome://editor/content/images/frown.gif);
}

#insert-wink {
   list-style-image:url(chrome://editor/content/images/wink.gif);
}

#insert-sick {
   list-style-image:url(chrome://editor/content/images/sick.gif);
}

#insert-smile5 {
   list-style-image:url(chrome://editor/content/images/smile.gif);
}

#insert-smile6 {
   list-style-image:url(chrome://editor/content/images/frown.gif);
}

#insert-smile7 {
   list-style-image:url(chrome://editor/content/images/wink.gif);
}



